@@ -14,7 +14,8 @@
 """ Device Layer
 
 This layer abstracts a complete :term:`target device` in a single object, which
-can be interacted without worries about how the actual communication is done.
+can be interacted with without worrying about how the actual communication is
+handled.
 
 To use this module create a :py:class:`~monk_tf.dev.Device` class.
 
@@ -34,12 +35,14 @@ logger = logging.getLogger(__name__)
 ############
 
 class DeviceException(Exception):
-    """ base class for Exceptions of the device layer
+    """ Base class for exceptions of the device layer.
     """
     pass
 
 class CantHandleException(DeviceException):
-    """ a request can't be handled by the connections of a :py:class:`~monk_tf.dev.Device`.
+    """
+    is raised when a request cannot be handled by the connections of a
+    :py:class:`~monk_tf.dev.Device`.
     """
     pass
 
@@ -51,14 +54,14 @@ class CantHandleException(DeviceException):
 ##############################
 
 class Device(object):
-    """ a :term:`target device` abstraction
+    """ is the API abstraction of a :term:`target device`.
     """
 
     def __init__(self, *args, **kwargs):
         """
         :param conns: list of connections. The following works as well::
 
-            Device(OneConnection(...), AnotherConnection(...),...)
+            ``Device(OneConnection(...), AnotherConnection(...),...)``
 
         :param name: Device name for logging purposes.
         """
@@ -69,9 +72,28 @@ class Device(object):
             self.name
         ))
 
+    @property
+    def ip_addrs(self):
+        """ get a list of all current IP addresses of device
+        """
+        self._logger.info("retreive IP addresses")
+        out = self.cmd(" | ".join([
+            "ifconfig -a",
+            "grep 'inet addr'",
+            "awk -F: '{print $2}'",
+            "awk '{print $1}'",]))
+        ips = out.split("\n")
+        if out and not out.startswith("127.0.0.1"):
+            self._logger.debug("found IP addresses:" + str(out))
+            return out.split('\n')
+        else:
+            raise NoIPException("couldn't receive any IP address")
+
     def cmd(self, msg):
-        """ send a :term:`shell command` to the :term:`target device`
+        """ Send a :term:`shell command` to the :term:`target device`.
+
         :param msg: the :term:`shell command`.
+
         :return: the standard output of the :term:`shell command`.
         """
         for connection in self.conns:
@@ -80,20 +102,17 @@ class Device(object):
                 connection.login()
                 return connection.cmd(msg)
             except conn.ConnectionException as excpt:
-                logger.exception("{}:{}:{}".format(
-                    self.name,
-                    connection.name,
-                    excpt
-                ))
+                self._logger.exception(excpt)
         # no connection was able to get to the return statement
-        raise CantHandleException("dev:'{}',conns:'{}':couldn't send cmd '{}'".format(
-            self.name,
-            map(str, self.conns),
-            msg,
+        raise CantHandleException(
+                "dev:'{}',conns:'{}':could not send cmd '{}'".format(
+                    self.name,
+                    map(str, self.conns),
+                    msg,
         ))
 
     def __del__(self):
-        """ make sure all connections get closed on delete
+        """ Make sure all connections get closed on delete.
         """
         for connection in self.conns:
             try:
